@@ -13,14 +13,15 @@ if (is.null(h)) h=floor(quantile(1:numgr,probs=0.05,na.rm=TRUE,type=4))
 else if (h<=0 ) stop("Error: incorrect knn value")
 tol=1e-19
 tol=diff(range(tt)*tol)
-vec=apply(tt,1,quantile,probs=((h+1)/numgr),type=4)+tol
+tol=1e-19
+if (cv) diag(tt)=Inf
+vec=apply(tt,1,quantile,probs=((h)/numgr),type=4)+tol
 rr=sweep(tt,1,vec,"/")
 rr=Ker(rr)
-if (cv) diag(rr)=0
-if (is.null(w)) w<-rep(1,ncol(rr))
-rr<-sweep(rr,2,w,FUN="*")   ## antes un 2
-#res=rr/apply(rr,1,sum,na.rm=TRUE)
-res=rr/rowSums(rr,na.rm=TRUE)
-return(res)
+#if (cv) diag(rr)=0
+if (!is.null(w)){ #w<-rep(1,ncol(rr))
+  rr<-sweep(rr,2,w,FUN="*") }  ## antes un 2
+#print(colSums(rr,na.rm=TRUE))
+rr=rr/rowSums(rr,na.rm=TRUE)
+return(rr)
 }
-
