@@ -88,7 +88,7 @@ if (nullans) {
     k = which.max(dep)    
     med = data[k, ]
     lista = which(dep >= quantile(dep, probs = trim,na.rm=TRUE))
-    mtrim = apply(fdataobj2$data[lista, ], 2, mean, na.rm = TRUE)
+    mtrim = apply(fdataobj2$data[lista, ,drop=FALSE], 2, mean, na.rm = TRUE)
     tr <- paste("RPD.tr", trim * 100, "%", sep = "")
     med <- fdata(med, tt, rtt, names1)
     mtrim <- fdata(mtrim, tt, rtt, names2)
