@@ -27,8 +27,8 @@
     t = fdataobj[["argvals"]]
     rtt <- fdataobj[["rangeval"]]
     names1 <- names2 <- names <- fdataobj[["names"]]
-    names1$main <- "depth.RP median"
-    names2$main <- paste("RP trim", trim * 100, "%", sep = "")
+    names1$main <- "depth.RT median"
+    names2$main <- paste("RT trim", trim * 100, "%", sep = "")
    
     if (is.fdata(proj)) {
         nproj <- nrow(proj)
@@ -75,17 +75,17 @@
         }
         else mtrim[j, ]=apply(fdataobj2$data[lista,],2,mean,na.rm=TRUE)       
     }
-    tr <- paste("RP.tr", trim * 100, "%", sep = "")
+    tr <- paste("RT.tr", trim * 100, "%", sep = "")
     med <- fdata(med, t, rtt, names1)
     mtrim <- fdata(mtrim, t, rtt, names2)
-    rownames(med$data) <- "RP.med"
+    rownames(med$data) <- "RT.med"
     rownames(mtrim$data) <- tr
     if (draw) {
         ans <- dep2
         ind1 <- !is.na(ans)
         cgray = 1 - (ans - min(ans, na.rm = TRUE))/(max(ans, 
             na.rm = TRUE) - min(ans, na.rm = TRUE))
-        plot(fdataobj2[ind1, ], col = gray(cgray[ind1]), main = "RP Depth")
+        plot(fdataobj2[ind1, ], col = gray(cgray[ind1]), main = "RT Depth")
         lines(mtrim, lwd = 2, col = "yellow")
         lines(med, col = "red", lwd = 2)
         legend("topleft", legend = c(tr, "Median"), lwd = 2,box.col=0, 
